summaryrefslogtreecommitdiffstats
path: root/korn/korncfgimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korn/korncfgimpl.cpp')
-rw-r--r--korn/korncfgimpl.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/korn/korncfgimpl.cpp b/korn/korncfgimpl.cpp
index 219cbcc0..0616e6fe 100644
--- a/korn/korncfgimpl.cpp
+++ b/korn/korncfgimpl.cpp
@@ -35,10 +35,10 @@
/*
* tqparent should be of type KDialogBase
*/
-KornCfgImpl::KornCfgImpl( TQWidget * tqparent, const char * name )
- : KornCfgWidget( tqparent, name ),
+KornCfgImpl::KornCfgImpl( TQWidget * parent, const char * name )
+ : KornCfgWidget( parent, name ),
_config( new KConfig( "kornrc" ) ),
_base( 0 )
{
@@ -47,9 +47,9 @@ KornCfgImpl::KornCfgImpl( TQWidget * tqparent, const char * name )
elbBoxes->setConfig( _config );
elbBoxes->setTitle( i18n( "Boxes" ) );
- connect( tqparent, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotOK() ) );
- connect( tqparent, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( slotCancel() ) );
- connect( tqparent, TQT_SIGNAL( applyClicked() ), this, TQT_SLOT( slotApply() ) );
+ connect( parent, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotOK() ) );
+ connect( parent, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( slotCancel() ) );
+ connect( parent, TQT_SIGNAL( applyClicked() ), this, TQT_SLOT( slotApply() ) );
connect( elbBoxes, TQT_SIGNAL( elementsSwapped( int, int ) ), this, TQT_SLOT( slotElementsSwapped( int, int ) ) );
connect( elbBoxes, TQT_SIGNAL( elementDeleted( int ) ), this, TQT_SLOT( slotElementDeleted( int ) ) );
@@ -35,10 +35,10 @@
/*
- * tqparent should be of type KDialogBase
+ * parent should be of type KDialogBase
*/